@@ -12,14 +12,14 @@ resolve_url <- function(endpoint_url, api_root) {
   if (grepl("^https?://", endpoint_url)) {
     return(endpoint_url)
   }
-  
+
   # For relative URLs, prepend the api_root
   # Remove any leading slash from endpoint_url to avoid double slashes
   endpoint_url <- sub("^/+", "", endpoint_url)
-  
+
   # Remove any trailing slash from api_root to avoid double slashes
   api_root <- sub("/+$", "", api_root)
-  
+
   return(paste0(api_root, "/", endpoint_url))
 }
 
@@ -36,3 +36,8 @@ json2tbl_impl <- function(data) {
   data <- dplyr::bind_rows(data)
   return(data)
 }
+
+
+are_credentials_expired <- function(credentials) {
+  as.numeric(Sys.time()) > credentials$expires_at
+}
